<a id="mypy-boto3-nimble"></a>

# mypy-boto3-nimble

[![PyPI - mypy-boto3-nimble](https://img.shields.io/pypi/v/mypy-boto3-nimble.svg?color=blue)](https://pypi.org/project/mypy-boto3-nimble)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-nimble.svg?color=blue)](https://pypi.org/project/mypy-boto3-nimble)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-nimble?color=blue)](https://pypistats.org/packages/mypy-boto3-nimble)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.NimbleStudio 1.19.9](https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/nimble.html#NimbleStudio)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.0.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-nimble docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_nimble/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-nimble](#mypy-boto3-nimble)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `NimbleStudio` service.

```bash
python -m pip install boto3-stubs[nimble]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[nimble]` in your environment:
  `python -m pip install 'boto3-stubs[nimble]'`

Both type checking and auto-complete should work for `NimbleStudio` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[nimble]` in your environment:
  `python -m pip install 'boto3-stubs[nimble]'`

Both type checking and auto-complete should work for `NimbleStudio` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[nimble]` in your environment:
  `python -m pip install 'boto3-stubs[nimble]'`
- Run `mypy` as usual

Type checking should work for `NimbleStudio` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[nimble]` in your environment:
  `python -m pip install 'boto3-stubs[nimble]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `NimbleStudio` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`NimbleStudioClient` provides annotations for `boto3.client("nimble")`.

```python
import boto3

from mypy_boto3_nimble import NimbleStudioClient

client: NimbleStudioClient = boto3.client("nimble")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: NimbleStudioClient = session.client("nimble")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_nimble.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_nimble import NimbleStudioClient
from mypy_boto3_nimble.paginator import (
    ListEulaAcceptancesPaginator,
    ListEulasPaginator,
    ListLaunchProfileMembersPaginator,
    ListLaunchProfilesPaginator,
    ListStreamingImagesPaginator,
    ListStreamingSessionsPaginator,
    ListStudioComponentsPaginator,
    ListStudioMembersPaginator,
    ListStudiosPaginator,
)

client: NimbleStudioClient = boto3.client("nimble")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_eula_acceptances_paginator: ListEulaAcceptancesPaginator = client.get_paginator("list_eula_acceptances")
list_eulas_paginator: ListEulasPaginator = client.get_paginator("list_eulas")
list_launch_profile_members_paginator: ListLaunchProfileMembersPaginator = client.get_paginator("list_launch_profile_members")
list_launch_profiles_paginator: ListLaunchProfilesPaginator = client.get_paginator("list_launch_profiles")
list_streaming_images_paginator: ListStreamingImagesPaginator = client.get_paginator("list_streaming_images")
list_streaming_sessions_paginator: ListStreamingSessionsPaginator = client.get_paginator("list_streaming_sessions")
list_studio_components_paginator: ListStudioComponentsPaginator = client.get_paginator("list_studio_components")
list_studio_members_paginator: ListStudioMembersPaginator = client.get_paginator("list_studio_members")
list_studios_paginator: ListStudiosPaginator = client.get_paginator("list_studios")
```

<a id="waiters-annotations"></a>

### Waiters annotations

`mypy_boto3_nimble.waiter` module contains type annotations for all waiters.

```python
from mypy_boto3_nimble import NimbleStudioClient
from mypy_boto3_nimble.waiter import (
    LaunchProfileDeletedWaiter,
    LaunchProfileReadyWaiter,
    StreamingImageDeletedWaiter,
    StreamingImageReadyWaiter,
    StreamingSessionDeletedWaiter,
    StreamingSessionReadyWaiter,
    StreamingSessionStoppedWaiter,
    StreamingSessionStreamReadyWaiter,
    StudioComponentDeletedWaiter,
    StudioComponentReadyWaiter,
    StudioDeletedWaiter,
    StudioReadyWaiter,
)

client: NimbleStudioClient = boto3.client("nimble")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
launch_profile_deleted_waiter: LaunchProfileDeletedWaiter = client.get_waiter("launch_profile_deleted")
launch_profile_ready_waiter: LaunchProfileReadyWaiter = client.get_waiter("launch_profile_ready")
streaming_image_deleted_waiter: StreamingImageDeletedWaiter = client.get_waiter("streaming_image_deleted")
streaming_image_ready_waiter: StreamingImageReadyWaiter = client.get_waiter("streaming_image_ready")
streaming_session_deleted_waiter: StreamingSessionDeletedWaiter = client.get_waiter("streaming_session_deleted")
streaming_session_ready_waiter: StreamingSessionReadyWaiter = client.get_waiter("streaming_session_ready")
streaming_session_stopped_waiter: StreamingSessionStoppedWaiter = client.get_waiter("streaming_session_stopped")
streaming_session_stream_ready_waiter: StreamingSessionStreamReadyWaiter = client.get_waiter("streaming_session_stream_ready")
studio_component_deleted_waiter: StudioComponentDeletedWaiter = client.get_waiter("studio_component_deleted")
studio_component_ready_waiter: StudioComponentReadyWaiter = client.get_waiter("studio_component_ready")
studio_deleted_waiter: StudioDeletedWaiter = client.get_waiter("studio_deleted")
studio_ready_waiter: StudioReadyWaiter = client.get_waiter("studio_ready")
```

<a id="literals"></a>

### Literals

`mypy_boto3_nimble.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_nimble.literals import (
    LaunchProfileDeletedWaiterName,
    LaunchProfilePersonaType,
    LaunchProfilePlatformType,
    LaunchProfileReadyWaiterName,
    LaunchProfileStateType,
    LaunchProfileStatusCodeType,
    ListEulaAcceptancesPaginatorName,
    ListEulasPaginatorName,
    ListLaunchProfileMembersPaginatorName,
    ListLaunchProfilesPaginatorName,
    ListStreamingImagesPaginatorName,
    ListStreamingSessionsPaginatorName,
    ListStudioComponentsPaginatorName,
    ListStudioMembersPaginatorName,
    ListStudiosPaginatorName,
    StreamingClipboardModeType,
    StreamingImageDeletedWaiterName,
    StreamingImageEncryptionConfigurationKeyTypeType,
    StreamingImageReadyWaiterName,
    StreamingImageStateType,
    StreamingImageStatusCodeType,
    StreamingInstanceTypeType,
    StreamingSessionDeletedWaiterName,
    StreamingSessionReadyWaiterName,
    StreamingSessionStateType,
    StreamingSessionStatusCodeType,
    StreamingSessionStoppedWaiterName,
    StreamingSessionStreamReadyWaiterName,
    StreamingSessionStreamStateType,
    StreamingSessionStreamStatusCodeType,
    StudioComponentDeletedWaiterName,
    StudioComponentInitializationScriptRunContextType,
    StudioComponentReadyWaiterName,
    StudioComponentStateType,
    StudioComponentStatusCodeType,
    StudioComponentSubtypeType,
    StudioComponentTypeType,
    StudioDeletedWaiterName,
    StudioEncryptionConfigurationKeyTypeType,
    StudioPersonaType,
    StudioReadyWaiterName,
    StudioStateType,
    StudioStatusCodeType,
    ServiceName,
    PaginatorName,
    WaiterName,
)

def check_value(value: LaunchProfileDeletedWaiterName) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_nimble.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_nimble.type_defs import (
    AcceptEulasRequestRequestTypeDef,
    AcceptEulasResponseTypeDef,
    ActiveDirectoryComputerAttributeTypeDef,
    ActiveDirectoryConfigurationTypeDef,
    ComputeFarmConfigurationTypeDef,
    CreateLaunchProfileRequestRequestTypeDef,
    CreateLaunchProfileResponseTypeDef,
    CreateStreamingImageRequestRequestTypeDef,
    CreateStreamingImageResponseTypeDef,
    CreateStreamingSessionRequestRequestTypeDef,
    CreateStreamingSessionResponseTypeDef,
    CreateStreamingSessionStreamRequestRequestTypeDef,
    CreateStreamingSessionStreamResponseTypeDef,
    CreateStudioComponentRequestRequestTypeDef,
    CreateStudioComponentResponseTypeDef,
    CreateStudioRequestRequestTypeDef,
    CreateStudioResponseTypeDef,
    DeleteLaunchProfileMemberRequestRequestTypeDef,
    DeleteLaunchProfileRequestRequestTypeDef,
    DeleteLaunchProfileResponseTypeDef,
    DeleteStreamingImageRequestRequestTypeDef,
    DeleteStreamingImageResponseTypeDef,
    DeleteStreamingSessionRequestRequestTypeDef,
    DeleteStreamingSessionResponseTypeDef,
    DeleteStudioComponentRequestRequestTypeDef,
    DeleteStudioComponentResponseTypeDef,
    DeleteStudioMemberRequestRequestTypeDef,
    DeleteStudioRequestRequestTypeDef,
    DeleteStudioResponseTypeDef,
    EulaAcceptanceTypeDef,
    EulaTypeDef,
    GetEulaRequestRequestTypeDef,
    GetEulaResponseTypeDef,
    GetLaunchProfileDetailsRequestRequestTypeDef,
    GetLaunchProfileDetailsResponseTypeDef,
    GetLaunchProfileInitializationRequestRequestTypeDef,
    GetLaunchProfileInitializationResponseTypeDef,
    GetLaunchProfileMemberRequestRequestTypeDef,
    GetLaunchProfileMemberResponseTypeDef,
    GetLaunchProfileRequestRequestTypeDef,
    GetLaunchProfileResponseTypeDef,
    GetStreamingImageRequestRequestTypeDef,
    GetStreamingImageResponseTypeDef,
    GetStreamingSessionRequestRequestTypeDef,
    GetStreamingSessionResponseTypeDef,
    GetStreamingSessionStreamRequestRequestTypeDef,
    GetStreamingSessionStreamResponseTypeDef,
    GetStudioComponentRequestRequestTypeDef,
    GetStudioComponentResponseTypeDef,
    GetStudioMemberRequestRequestTypeDef,
    GetStudioMemberResponseTypeDef,
    GetStudioRequestRequestTypeDef,
    GetStudioResponseTypeDef,
    LaunchProfileInitializationActiveDirectoryTypeDef,
    LaunchProfileInitializationScriptTypeDef,
    LaunchProfileInitializationTypeDef,
    LaunchProfileMembershipTypeDef,
    LaunchProfileTypeDef,
    LicenseServiceConfigurationTypeDef,
    ListEulaAcceptancesRequestRequestTypeDef,
    ListEulaAcceptancesResponseTypeDef,
    ListEulasRequestRequestTypeDef,
    ListEulasResponseTypeDef,
    ListLaunchProfileMembersRequestRequestTypeDef,
    ListLaunchProfileMembersResponseTypeDef,
    ListLaunchProfilesRequestRequestTypeDef,
    ListLaunchProfilesResponseTypeDef,
    ListStreamingImagesRequestRequestTypeDef,
    ListStreamingImagesResponseTypeDef,
    ListStreamingSessionsRequestRequestTypeDef,
    ListStreamingSessionsResponseTypeDef,
    ListStudioComponentsRequestRequestTypeDef,
    ListStudioComponentsResponseTypeDef,
    ListStudioMembersRequestRequestTypeDef,
    ListStudioMembersResponseTypeDef,
    ListStudiosRequestRequestTypeDef,
    ListStudiosResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    NewLaunchProfileMemberTypeDef,
    NewStudioMemberTypeDef,
    PaginatorConfigTypeDef,
    PutLaunchProfileMembersRequestRequestTypeDef,
    PutStudioMembersRequestRequestTypeDef,
    ResponseMetadataTypeDef,
    ScriptParameterKeyValueTypeDef,
    SharedFileSystemConfigurationTypeDef,
    StartStreamingSessionRequestRequestTypeDef,
    StartStreamingSessionResponseTypeDef,
    StartStudioSSOConfigurationRepairRequestRequestTypeDef,
    StartStudioSSOConfigurationRepairResponseTypeDef,
    StopStreamingSessionRequestRequestTypeDef,
    StopStreamingSessionResponseTypeDef,
    StreamConfigurationCreateTypeDef,
    StreamConfigurationTypeDef,
    StreamingImageEncryptionConfigurationTypeDef,
    StreamingImageTypeDef,
    StreamingSessionStreamTypeDef,
    StreamingSessionTypeDef,
    StudioComponentConfigurationTypeDef,
    StudioComponentInitializationScriptTypeDef,
    StudioComponentSummaryTypeDef,
    StudioComponentTypeDef,
    StudioEncryptionConfigurationTypeDef,
    StudioMembershipTypeDef,
    StudioTypeDef,
    TagResourceRequestRequestTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateLaunchProfileMemberRequestRequestTypeDef,
    UpdateLaunchProfileMemberResponseTypeDef,
    UpdateLaunchProfileRequestRequestTypeDef,
    UpdateLaunchProfileResponseTypeDef,
    UpdateStreamingImageRequestRequestTypeDef,
    UpdateStreamingImageResponseTypeDef,
    UpdateStudioComponentRequestRequestTypeDef,
    UpdateStudioComponentResponseTypeDef,
    UpdateStudioRequestRequestTypeDef,
    UpdateStudioResponseTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> AcceptEulasRequestRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-nimble` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-nimble docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_nimble/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
